#!/usr/bin/env python

"""
Document format translator manifest.

Copyright (C) 2017, 2018, 2021, 2023 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from moinformat.imports import get_extensions, get_mapping, get_modules

# Define an attribute mapping names to modules.

modules = get_modules(__file__, __name__)

# Obtain all translators.

# Use module paths to register the handlers:
# output_format.input_format -> translator

def get_formats(n, m):

    """
    Given module name 'n', inspect the translator in module 'm', returning a
    list of format names.
    """

    l = []
    for output_format in m.translator.formats:
        for input_format in m.translator.input_formats:
            l.append("%s.%s" % (output_format, input_format))
    return l

translators = get_mapping(modules, get_formats, lambda m: m.translator)

# vim: tabstop=4 expandtab shiftwidth=4
